==> share_it-0.3.0%2B1.tar.gz: lib/share_it_ios.dart <==
part of share_it;

class IOSDataType extends RawEnum<String> {
  const IOSDataType._(String dataType) : super(dataType);
  static const plainText = const IOSDataType._("text");
  static const image = const IOSDataType._("image");
  static const uiImage = const IOSDataType._("uiImage");
  static const _link = const IOSDataType._("link");
  static const file = const IOSDataType._("file");
}

class ShareItIOSParameters implements ShareItParametersMixin {

  final IOSDataType type;

  /// A path (URL in iOS) if is a file, or text if is raw text
  final String content;

  const ShareItIOSParameters.plainText(this.content)
      : type = IOSDataType.plainText;

  const ShareItIOSParameters.link(this.content)
      : type = IOSDataType._link;

  const ShareItIOSParameters.file({@required String path, @required this.type})
      : this.content = path;

  ShareItIOSParameters._file({@required String path, @required RawEnum<String> rawType})
      : this.content = path,
        this.type = IOSDataType._(rawType.rawValue);

  Map<String, dynamic> toMap() {
    return {'type': type.rawValue, 'content': content ?? ''};
  }
}

class _IOSActivityViewController implements ShareItMixin {

  final ShareItIOSParameters parameters;
  const _IOSActivityViewController({@required this.parameters});

  @override
  Future<bool> present() async {
    final result = await ShareIt._channel.invokeMethod(
      K.iOSInvokeShareMethod,
      parameters.toMap()
    );
    if (result == true) {
      return true;
    } else {
      return Future.error(result);
    }
  }
}

==> share_it-0.5.1%2B1.tar.gz: lib/share_it_ios.dart <==
part of share_it;

class IOSDataType extends _RawEnum<String> {
  const IOSDataType._(String dataType) : super(dataType);
  static const plainText = const IOSDataType._("text");
  static const image = const IOSDataType._("image");
  static const uiImage = const IOSDataType._("uiImage");
  static const _link = const IOSDataType._("link");
  static const file = const IOSDataType._("file");
}

class ShareItIOSParameters implements ShareItParametersMixin {

  final IOSDataType type;

  /// A path (URL in iOS) if is a file, or text if is raw text
  final String content;

  const ShareItIOSParameters.plainText(this.content)
      : type = IOSDataType.plainText;

  const ShareItIOSParameters.link(this.content)
      : type = IOSDataType._link;

  const ShareItIOSParameters.file({@required String path, @required this.type})
      : this.content = path;

  ShareItIOSParameters._file({@required String path, @required _RawEnum<String> rawType})
      : this.content = path,
        this.type = IOSDataType._(rawType.rawValue);

  Map<String, dynamic> toMap() {
    return {'type': type.rawValue, 'content': content ?? ''};
  }
}

class _IOSActivityViewController implements ShareItMixin {

  final List<ShareItIOSParameters> parameters;
  const _IOSActivityViewController({@required this.parameters});

  @override
  Future<bool> present() async {
    // the iOS plugin automatically returns a value to avoid blocking the UI
    // https://github.com/flutter/flutter/issues/22024
    // that's why I use a timeout here, if something bad happens and the alert never
    // gets presented, after 10s I assume there was an error
    final result = await ShareIt._channel.invokeMethod(
      ShareItConstants.iOSInvokeShareMethod,
      parameters.map((p) => p.toMap()).toList()
    ).timeout(
      const Duration(seconds: 10),
      onTimeout: () => false
    );
    if (result == true) {
      return true;
    } else {
      return Future.error(result);
    }
  }
}
